.. _reference:

Reference
*********

.. toctree::
   :maxdepth: 1

    Automatically-generated code documentation <auto-generated>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
